import Enzyme from "enzyme";
import React from "react";

import { Select } from "../select";
import { SelectContainer } from "../select-container";
import { SelectOption } from "../select-option";

import { hasProperties, testGenericPropTypes } from "@/__tests__/testing";

describe("Select component", () => {
  hasProperties(Select, {
    Container: SelectContainer,
    Option: SelectOption,
    defaultProps: { as: "select" },
  });

  it("should render as the default element", () => {
    const wrapper = Enzyme.shallow(<Select />);
    expect(wrapper.is("select")).toBe(true);
  });

  it("should render as a custom component", () => {
    const as = "span";
    const wrapper = Enzyme.shallow(<Select as={as} />);
    expect(wrapper.is(as)).toBe(true);
  });

  it("should forward ref", () => {
    const ref = React.createRef<HTMLSelectElement>();
    // Enzyme owns outer ref: https://github.com/airbnb/enzyme/issues/1852
    const wrapper = Enzyme.mount(
      <div>
        <Select ref={ref} />
      </div>,
    );
    try {
      expect(ref.current).toBe(wrapper.find("select").instance());
    } finally {
      wrapper.unmount();
    }
  });

  it("should preserve custom className", () => {
    const className = "foo";
    const wrapper = Enzyme.shallow(<Select className={className} />);
    expect(wrapper.hasClass(className)).toBe(true);
  });

  describe("propTypes", () => {
    const { propTypes } = Select;
    testGenericPropTypes(propTypes);
  });
});
